/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geronimo.samples.javaee6.restfulorder.converter;

import java.net.URI;
import org.apache.geronimo.samples.javaee6.restfulorder.entities.Restfulorder;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlAttribute;
import javax.ws.rs.core.UriBuilder;
import javax.persistence.EntityManager;



@XmlRootElement(name = "restfulorder")
public class RestfulorderConverter {
    private Restfulorder entity;
    private URI uri;
    private int expandLevel;
  
    /** Creates a new instance of RestfulorderConverter */
    public RestfulorderConverter() {
        entity = new Restfulorder();
    }

    /**
     * Creates a new instance of RestfulorderConverter.
     *
     * @param entity associated entity
     * @param uri associated uri
     * @param expandLevel indicates the number of levels the entity graph should be expanded@param isUriExtendable indicates whether the uri can be extended
     */
    public RestfulorderConverter(Restfulorder entity, URI uri, int expandLevel, boolean isUriExtendable) {
        this.entity = entity;
        this.uri = (isUriExtendable) ? UriBuilder.fromUri(uri).path(entity.getId() + "/").build() : uri;
        this.expandLevel = expandLevel;
    }

    /**
     * Creates a new instance of RestfulorderConverter.
     *
     * @param entity associated entity
     * @param uri associated uri
     * @param expandLevel indicates the number of levels the entity graph should be expanded
     */
    public RestfulorderConverter(Restfulorder entity, URI uri, int expandLevel) {
        this(entity, uri, expandLevel, false);
    }

    /**
     * Getter for id.
     *
     * @return value for id
     */
    @XmlElement
    public Integer getId() {
        return (expandLevel > 0) ? entity.getId() : null;
    }

    /**
     * Setter for id.
     *
     * @param value the value to set
     */
    public void setId(Integer value) {
        entity.setId(value);
    }

    /**
     * Getter for customer.
     *
     * @return value for customer
     */
    @XmlElement
    public String getCustomer() {
        return (expandLevel > 0) ? entity.getCustomer() : null;
    }

    /**
     * Setter for customer.
     *
     * @param value the value to set
     */
    public void setCustomer(String value) {
        entity.setCustomer(value);
    }

    /**
     * Getter for seller.
     *
     * @return value for seller
     */
    @XmlElement
    public String getSeller() {
        return (expandLevel > 0) ? entity.getSeller() : null;
    }

    /**
     * Setter for seller.
     *
     * @param value the value to set
     */
    public void setSeller(String value) {
        entity.setSeller(value);
    }

    /**
     * Getter for productname.
     *
     * @return value for productname
     */
    @XmlElement
    public String getProductname() {
        return (expandLevel > 0) ? entity.getProductname() : null;
    }

    /**
     * Setter for productname.
     *
     * @param value the value to set
     */
    public void setProductname(String value) {
        entity.setProductname(value);
    }

    /**
     * Getter for price.
     *
     * @return value for price
     */
    @XmlElement
    public Double getPrice() {
        return (expandLevel > 0) ? entity.getPrice() : null;
    }

    /**
     * Setter for price.
     *
     * @param value the value to set
     */
    public void setPrice(Double value) {
        entity.setPrice(value);
    }

    /**
     * Getter for quantity.
     *
     * @return value for quantity
     */
    @XmlElement
    public Integer getQuantity() {
        return (expandLevel > 0) ? entity.getQuantity() : null;
    }

    /**
     * Setter for quantity.
     *
     * @param value the value to set
     */
    public void setQuantity(Integer value) {
        entity.setQuantity(value);
    }

    /**
     * Returns the URI associated with this converter.
     *
     * @return the uri
     */
    @XmlAttribute
    public URI getUri() {
        return uri;
    }

    /**
     * Sets the URI for this reference converter.
     *
     */
    public void setUri(URI uri) {
        this.uri = uri;
    }

    /**
     * Returns the Restfulorder entity.
     *
     * @return an entity
     */
    @XmlTransient
    public Restfulorder getEntity() {
        if (entity.getId() == null) {
            RestfulorderConverter converter = UriResolver.getInstance().resolve(RestfulorderConverter.class, uri);
            if (converter != null) {
                entity = converter.getEntity();
            }
        }
        return entity;
    }

    /**
     * Returns the resolved Restfulorder entity.
     *
     * @return an resolved entity
     */
    public Restfulorder resolveEntity(EntityManager em) {
        return entity;
    }
}
